==> cbol-1.5.tgz: cbol-1.5/audio_hb.php <==
<?php
require("config.php");
$version=(int)$_REQUEST['version'];
$vname=array("","xy","Ȯa","sF");
$vdir=array("unv1","Taiwanese","haka","Cantonese1");
$ENGS=array("Gen","Ex","Lev","Num","Deut","Josh","Judg","Ruth",
"1 Sam","2 Sam","1 Kin","2 Kin","1 Chr","2 Chr","Ezra","Neh",
"Esth","Job","Ps","Prov","Eccl","Song","Is","Jer","Lam","Ezek",
"Dan","Hos","Joel","Amos","Obad","Jon","Mic","Nah","Hab","Zeph",
"Hag","Zech","Mal",
"Matt","Mark","Luke","John","Acts","Rom","1 Cor","2 Cor","Gal",
"Eph","Phil","Col","1 Thess","2 Thess","1 Tim","2 Tim","Titus",
"Philem","Heb","James","1 Pet","2 Pet","1 John","2 John","3 John",
"Jude","Rev");
$ENGF=array("Genesis","Exodus","Leviticus","Numbers","Deuteronomy","Joshua","Judges","Ruth",
"First Samuel","Second Samuel","First Kings","Second Kings","First Chronicles","Second Chronicles","Ezra","Nehemiah",
"Esther","Job","Psalms","Proverbs","Ecclesiastes","Song of Solomon","Isaiah","Jeremiah","Lamentations","Ezekiel",
"Daniel","Hosea","Joel","Amos","Obadiah","Jonah","Micah","Nahum","Habakkuk","Zephaniah",
"Haggai","Zechariah","Malachi",
"Matthew","Mark","Luke","John","Acts","Romans","First Corinthians","Second Corinthians","Galatians",
"Ephesians","Philippians","Colossians","First Thessalonians","Second Thessalonians","First Timothy","Second Timothy","Titus",
"Philemon","Hebrews","James","First Peter","Second Peter","First John","second John","Third John",
"Jude","Revelation");
$CHINESES=array("","X","Q","","","","h","o",
"W","U","W","U","NW","NU","","",
"","B","","e","","q","","C","s","",
"","","ҭ","","X","","","E","","f",
"","","",
"","i","","","{","ù","Le","L","[",
"","","","e","","e","","h",
"","","","e","","@","G","T",
"S","");
$CHINESEF=array("Х@O","XJΰO","QO","ưO","өRO","ѨȰO","hvO","oO",
"հOW","հOU","CW","CU","NӤW","NӤU","H԰O","Ʀ̰O",
"HO","BO","ֽg","e","ǹD","q","HɨȮ","CQ̮","CQ̫sq","H赲",
"Hz","","ҭ","q","XکȮ","","{","E","ڨ","f",
"Ӯ","{QȮ","԰",
"Ӻ֭","i֭","[֭","֭","Ϯ{","ù","Lhe","Lh","[ԤӮ",
"HҮ","̥ߤ","qù","ù{e","ù{","ӫe","ӫ","h",
"̧Q","ƧBӮ","U","oe","o","@","G","T",
"Sj","ҥܿ");
$verse=array(50,40,27,36,34,24,21,4,31,24,22,25,29,36,10,13,10,42,150,31,12,8,66,52,5,48,12,14,3,9,1,4,7,3,3,3,2,14,4,
             28,16,24,21,28,16,16,13,6,6,4,4,5,3,6,4,3,1,13,5,5,3,5,1,1,1,22);
 echo "<h2>{$vname[$version]}ntg</h2>";
 echo " <font color=\"green\"><a href=\"{$ftpbase}\">Uɮ</a>  <a href=\"{$audioabout}\">ytg</a></font><p>";
 for ($i=0;$i<66;$i++)
 {
   $ii=$i+1;
   $nstr="";
   $flag=0;
   for ($j=1;$j<=$verse[$i];$j++)
   {
     $taifile="/home/stream/bible/".$vdir[$version]."/{$ii}/{$ii}_{$j}.mp3";
     if (is_file($taifile))
     {
	$nstr=$nstr."<a href=\"{$audiobase}{$vdir[$version]}/{$ii}/{$ii}_{$j}.mp3\">$j</a>  ";
	$flag=1;
     }
          
   }
     if ($flag==1)
     {
   	echo "<font size=\"+1\" color=\"red\">{$CHINESEF[$i]}</font><p>\n";
     	echo $nstr;
   	echo "<p>\n";
     }
 }
?>

==> cbol-3.0.tgz: cbol-3.0/audio_hb.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=big5" />
<title>ntg</title>
</head>
<body>
<?php
require("config.php");
$version=(int)$_REQUEST['version'];
$vname=array("MX","xy","Ȯa","sF",'{NĶ');
$vdir=array("unv1","Taiwanese","haka","Cantonese1",'tcv');
$ENGS=array("Gen","Ex","Lev","Num","Deut","Josh","Judg","Ruth",
"1 Sam","2 Sam","1 Kin","2 Kin","1 Chr","2 Chr","Ezra","Neh",
"Esth","Job","Ps","Prov","Eccl","Song","Is","Jer","Lam","Ezek",
"Dan","Hos","Joel","Amos","Obad","Jon","Mic","Nah","Hab","Zeph",
"Hag","Zech","Mal",
"Matt","Mark","Luke","John","Acts","Rom","1 Cor","2 Cor","Gal",
"Eph","Phil","Col","1 Thess","2 Thess","1 Tim","2 Tim","Titus",
"Philem","Heb","James","1 Pet","2 Pet","1 John","2 John","3 John",
"Jude","Rev");
$ENGF=array("Genesis","Exodus","Leviticus","Numbers","Deuteronomy","Joshua","Judges","Ruth",
"First Samuel","Second Samuel","First Kings","Second Kings","First Chronicles","Second Chronicles","Ezra","Nehemiah",
"Esther","Job","Psalms","Proverbs","Ecclesiastes","Song of Solomon","Isaiah","Jeremiah","Lamentations","Ezekiel",
"Daniel","Hosea","Joel","Amos","Obadiah","Jonah","Micah","Nahum","Habakkuk","Zephaniah",
"Haggai","Zechariah","Malachi",
"Matthew","Mark","Luke","John","Acts","Romans","First Corinthians","Second Corinthians","Galatians",
"Ephesians","Philippians","Colossians","First Thessalonians","Second Thessalonians","First Timothy","Second Timothy","Titus",
"Philemon","Hebrews","James","First Peter","Second Peter","First John","second John","Third John",
"Jude","Revelation");
$CHINESES=array("","X","Q","","","","h","o",
"W","U","W","U","NW","NU","","",
"","B","","e","","q","","C","s","",
"","","ҭ","","X","","","E","","f",
"","","",
"","i","","","{","ù","Le","L","[",
"","","","e","","e","","h",
"","","","e","","@","G","T",
"S","");
$CHINESEF=array("Х@O","XJΰO","QO","ưO","өRO","ѨȰO","hvO","oO",
"հOW","հOU","CW","CU","NӤW","NӤU","H԰O","Ʀ̰O",
"HO","BO","ֽg","e","ǹD","q","HɨȮ","CQ̮","CQ̫sq","H赲",
"Hz","","ҭ","q","XکȮ","","{","E","ڨ","f",
"Ӯ","{QȮ","԰",
"Ӻ֭","i֭","[֭","֭","Ϯ{","ù","Lhe","Lh","[ԤӮ",
"HҮ","̥ߤ","qù","ù{e","ù{","ӫe","ӫ","h",
"̧Q","ƧBӮ","U","oe","o","@","G","T",
"Sj","ҥܿ");
$verse=array(50,40,27,36,34,24,21,4,31,24,22,25,29,36,10,13,10,42,150,31,12,8,66,52,5,48,12,14,3,9,1,4,7,3,3,3,2,14,4,
             28,16,24,21,28,16,16,13,6,6,4,4,5,3,6,4,3,1,13,5,5,3,5,1,1,1,22);
 echo "<h2>{$vname[$version]}ntg</h2>";
 echo " <font color=\"green\"><a href=\"{$ftpbase}\" target=\"ftp\">Uɮ</a> <a href=\"{$ftpbase1}\" target=\"ftp\">Uɮ(_^</a>  <a href=\"{$audioabout}\">ytg</a></font> <a href=\"http://www.winamp.com/\">iWinampuWť</a><p />";
 for ($i=0;$i<66;$i++)
 {
   $ii=$i+1;
   $nstr="";
   $flag=0;
   for ($j=1;$j<=$verse[$i];$j++)
   {
     $nj=sprintf('%03d',$j);
     $taifile="/home/stream/bible/".$vdir[$version]."/{$ii}/{$ii}_{$nj}.mp3";
     $m3ufile="/home/stream/bible/".$vdir[$version]."/{$ii}/{$ii}_{$nj}.m3u";
     if (is_file($taifile))
     {
	if  (!is_file($m3ufile))
	{
		$m3upt=fopen($m3ufile,'w');
		fwrite($m3upt,"{$audiobase}{$vdir[$version]}/{$ii}/{$ii}_{$nj}.mp3");
		fclose($m3upt);
	}
	$nstr=$nstr."<a href=\"{$audiobase}{$vdir[$version]}/{$ii}/{$ii}_{$nj}.m3u\">$j</a>  ";
	$flag=1;
     }
          
   }
     if ($flag==1)
     {
   	echo "<font size=\"+1\" color=\"red\">{$CHINESEF[$i]}</font><p>\n";
     	echo $nstr;
   	echo "<p>\n";
     }
 }
?>
</body>
</html>
